import { logger } from './logger.js';
import { startTimers, stopTimers, resumeTimer } from './timer.loop.js';
import { createTimer } from './timer.repository.js';
import { TimerScreen } from "./timer-screen.js";

let isPaused = true;

console.debug('Timer module booted!');

Hooks.on('init', function() {
  logger.log('Timer module init');
});

Hooks.on('ready', function(details) {
  logger.log('Timer module ready:', details);

  startTimers();
  isPaused = false;

  addSomeTimers();

  const screen = new TimerScreen();
  logger.log(screen);
  const result = screen.render(true);
  logger.log(result);

});

Hooks.on('error', function(location, error, payload) {
  logger.error(`Timer module error at ${location}`, error, payload ?? 'no payload');
});

Hooks.on('pauseGame', function(paused) {
  if (paused) {
    logger.log('Game paused.');
    if (!isPaused) {
      stopTimers();
      isPaused = true;
    }
  } else {
    logger.log('Game unpaused');
    if (isPaused) {
      startTimers()
      isPaused = false;
    }
  }
});


function addSomeTimers() {
  // TODO: Remove this debugging aid.
  const pausedTimerName = createTimer('10');
  createTimer('10');
  createTimer('01:10', '', true);
  createTimer('01:10', '', false);
  createTimer('00:00:00', 'long', false);
  createTimer('10');
  createTimer('10');
  createTimer('10');
  createTimer('10');
  createTimer('10');
  createTimer('10');

  setTimeout(() => resumeTimer(pausedTimerName), 5000);

  createTimer('5', 'my timer', true);
/*
  const flippyNamedTimer = createTimer('00:05', 'flippy', true);

  let isOn = true;
  setInterval(() => {
    if (isOn) {
      pauseTimer(flippyNamedTimer);
      isOn = false;
    } else {
      resumeTimer(flippyNamedTimer);
      isOn = true;
    }
  }, 2200);
  */
}

